# Generated by roxygen2: do not edit by hand

S3method("[<-",hms)
S3method("[[",hms)
S3method("units<-",hms)
S3method(as.POSIXct,hms)
S3method(as.POSIXlt,hms)
S3method(as.character,hms)
S3method(as.hms,POSIXlt)
S3method(as.hms,POSIXt)
S3method(as.hms,default)
S3method(as_hms,default)
S3method(c,hms)
S3method(format,hms)
S3method(print,hms)
S3method(unique,hms)
S3method(vec_cast,hms)
S3method(vec_cast.POSIXct,hms)
S3method(vec_cast.POSIXlt,hms)
S3method(vec_cast.character,hms)
S3method(vec_cast.difftime,hms)
S3method(vec_cast.double,hms)
S3method(vec_cast.hms,POSIXct)
S3method(vec_cast.hms,POSIXlt)
S3method(vec_cast.hms,character)
S3method(vec_cast.hms,default)
S3method(vec_cast.hms,difftime)
S3method(vec_cast.hms,double)
S3method(vec_cast.hms,hms)
S3method(vec_cast.hms,integer)
S3method(vec_cast.integer,hms)
S3method(vec_ptype2,hms)
S3method(vec_ptype2.difftime,hms)
S3method(vec_ptype2.hms,default)
S3method(vec_ptype2.hms,difftime)
S3method(vec_ptype2.hms,hms)
S3method(vec_ptype_abbr,hms)
S3method(vec_ptype_full,hms)
export(as.hms)
export(as_hms)
export(hms)
export(is.hms)
export(is_hms)
export(new_hms)
export(parse_hm)
export(parse_hms)
export(round_hms)
export(trunc_hms)
export(vec_cast.hms)
export(vec_ptype2.hms)
import(rlang)
import(vctrs)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,expect_deprecated)
importFrom(methods,setOldClass)
importFrom(pkgconfig,get_config)
