#' @details
#' `r lifecycle::badge("stable")`
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom cli cli_abort
#' @importFrom cli cli_text
#' @importFrom cli cli_warn
#' @importFrom lifecycle deprecate_soft
#' @importFrom lifecycle deprecate_warn
#' @importFrom lifecycle expect_deprecated
#' @importFrom methods setOldClass
#' @importFrom pkgconfig get_config
#' @import rlang
#' @import vctrs
## usethis namespace: end
NULL
